#include "KMotionDef.h"

estop_test()	// this function monitors for any estop condition
{
	int estopMes = 0;	// used for message displaying after estop kill has occured (message's are blocking)
	// **** Start E-Stop Monitoring ****
	
	// if we're still initializing, then we don't check TC
	if(!ReadBit(INIT)) {
		// TC monitor - If we don't have TCOK other than when TC is active, then we have an issue
		if(!ReadBit(TCOK) && !ReadBit(TCACTIVE)) {
			ClearBit(SYSTEMOK);
			estopMes = ESTCFAIL;
			printf("ESTOP TCOK and TCACTIVE low\n");
		}
	}
	
	// if external estop circuit is lost, or if any other input that should be active disappears, we have an issue
	if (!ReadBit(ESTOP)){
		ClearBit(SYSTEMOK);
		estopMes = ESTRIGGD;
		//printf("External EStop\n");
	}
	
	if (!ReadBit(XREADY)){
		ClearBit(SYSTEMOK);
		estopMes = ESXFAIL;
		//printf("X not ready\n");
	}
	
	if (!ReadBit(ZREADY)){
		ClearBit(SYSTEMOK);
		estopMes = ESZFAIL;
		//printf("Z not ready\n");
	}
	
	// if either channel is not enabled, and we're not in the homing routine which needs to disable axis, we have an issue
	if ((!ch0->Enable || !ch1->Enable) && !ReadBit(INHOMING)){
		ClearBit(SYSTEMOK);
		estopMes = ESXZFAIL;
		//printf("X or Z not enabled\n");
	}
	
	// if spindle axis has faulted when it should be running, we need to stop things
	if (!ch2->Enable && persist.UserData[SPDL_STATEVAR] != 0){
		ClearBit(SYSTEMOK);
		estopMes = ESSPDL;
		printf("Spindle disabled when running\n");
	}
	
	// if system ok, then no faults found and we can enable servos
	if(!ReadBit(SYSTEMOK) && !ReadBit(ESTOPHANDLED))
	{					//kill everything
		printf("EStop not handled\n");
		ClearBit(SERVOENABLE);	// (it maybe gets enabled elsewhere, but we kill everything here, just to make sure)
		DisableAxis(0);
		DisableAxis(1);
		DisableAxis(2);
		ClearBit(TCALLOW);		
		ClearBit(SERVORESET);
		ClearBit(COOLANT);
		ClearBit(SPDLFOR);
		ClearBit(SPDLREV);
		persist.UserData[SPDL_STATEVAR] = 0;
		ClearBit(INHOMING);
		ClearBit(SYSTEMOK);
		ClearBit(TCACTIVE);
		ClearBit(JOGALLOWED);
		DoPC(PC_COMM_ESTOP);	// finally we'll tell KMotionCNC to EStop
		printf("PC_COMM_ESTOP requested\n"); 
		SetBit(ESTOPHANDLED);
		printf("ESTOPHANDLED set\n");
		
				//double msgdel = Time_sec()+2;
				//while(msgdel > Time_sec()){}
				//printf("in estopMes\n");
		switch(estopMes)
			{
				case(ESTCFAIL):		// TC failure
					{
						MsgBoxNoWait("ESTOP!! ToolChanger - No OK signal",MB_OK|MB_ICONEXCLAMATION);
						break;
					}
				case(ESTRIGGD):
					{
						MsgBoxNoWait("ESTOP!! E-stop activated, or Axis drive in error",MB_OK|MB_ICONEXCLAMATION);
						break;
					}
				case(ESXZFAIL):
					{
						MsgBoxNoWait("ESTOP!! X or Z axis disabled while not in homing",MB_OK|MB_ICONEXCLAMATION);
						break;
					}
				case(ESXFAIL):
					{
						MsgBoxNoWait("ESTOP!! X axis drive not ready",MB_OK|MB_ICONEXCLAMATION);
						break;
					}
				case(ESZFAIL):
					{
						MsgBoxNoWait("ESTOP!! Z axis drive not ready",MB_OK|MB_ICONEXCLAMATION);
						break;
					}
				case(ESSPDL):
					{
						MsgBoxNoWait("ESTOP!! Spindle disabled",MB_OK|MB_ICONEXCLAMATION);
						break;
					}
			}
		/*if(ReadBit(ESTOPHANDLED)){
			printf("ESTOPHANDLED set\n");
		} else {
			printf("ESTOPHANDLED not set\n");
		}*/
	}
	// **** End E-Stop Monitoring ****
}

main()
{

}
